﻿using System;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

namespace OutlookBar_GroupBinding
{
    public class ViewModel : INotifyPropertyChanged
    {
        private ObservableCollection<Group> _groups;
        public ObservableCollection<Group> Groups
        {
            get { return _groups; }
            set
            {
                _groups = value;
                OnPropertyChanged("Groups");
            }
        }

        public ViewModel()
        {
            Groups = GenerateGroups();
        }

        private ObservableCollection<Group> GenerateGroups()
        {
            ObservableCollection<Group> groups = new ObservableCollection<Group>();

            //create the mail group with menu items
            var mailGroup = new Group()
            {
                Title = "Mail",
                LargeImagePath = @"/OutlookBar_GroupBinding;component/Images/Mail32.png",
                SmallImagePath = @"/OutlookBar_GroupBinding;component/Images/Mail16.png"
            };
            var rootMailItem = new MenuItem() { Title = "Personal Folders", IsExpanded = true };
            rootMailItem.Children.Add(new MenuItem() { Title = "Inbox", ImagePath = @"/OutlookBar_GroupBinding;component/Images/InboxFolder16.png" });
            rootMailItem.Children.Add(new MenuItem() { Title = "Drafts", ImagePath = @"/OutlookBar_GroupBinding;component/Images/DraftsFolder16.png" });
            rootMailItem.Children.Add(new MenuItem() { Title = "Sent Items", ImagePath = @"/OutlookBar_GroupBinding;component/Images/SentFolder16.png" });
            rootMailItem.Children.Add(new MenuItem() { Title = "Deleted Items", ImagePath = @"/OutlookBar_GroupBinding;component/Images/DeletedFolder16.png" });
            mailGroup.Items.Add(rootMailItem);

            //create the contacts group with menu items
            var contactsGroup = new Group()
            {
                Title = "Contacts",
                LargeImagePath = @"/OutlookBar_GroupBinding;component/Images/Contact32.png",
                SmallImagePath = @"/OutlookBar_GroupBinding;component/Images/Contact16.png"
            };
            var rootContactItem = new MenuItem() { Title = "My Contacts", IsExpanded = true };
            rootContactItem.Children.Add(new MenuItem() { Title = "Suggested Contacts", ImagePath = @"/OutlookBar_GroupBinding;component/Images/Contact16.png" });
            rootContactItem.Children.Add(new MenuItem() { Title = "Contacts", ImagePath = @"/OutlookBar_GroupBinding;component/Images/Contact16.png" });
            contactsGroup.Items.Add(rootContactItem);

            groups.Add(mailGroup);
            groups.Add(contactsGroup);

            return groups;
        }

        public event PropertyChangedEventHandler PropertyChanged;
        protected void OnPropertyChanged(string propertyname)
        {
            var handler = PropertyChanged;
            if (handler != null)
                handler(this, new PropertyChangedEventArgs(propertyname));
        }
    }
}
